from setuptools import setup

setup(name='expiringdict',
      description='Expiring Dictionary',
      author='Mailgun (Rackspace)',
      author_email='admin@mailgunhq.com',
      version='1.0',
      py_modules=['expiringdict'],
      zip_safe=True,
      )
